# insults

A Python CLI module helping you cuss at your users.

# Usage

``` import insults ```

.....

# Deployment

Install using ```pip install insults```

Build using ```python setup.py sdist bdist_wheel```

Upload using ```twine upload dist/*```
